@@ -5,7 +5,8 @@ mapdeckGeojsonDependency <- function() {
 			name = "geojson",
 			version = "1.0.0",
 			src = system.file("htmlwidgets/lib/geojson", package = "mapdeck"),
-			script = c("geojson.js")
+			script = c("geojson.js"),
+			all_files = FALSE
 		)
 	)
 }
@@ -20,14 +21,32 @@ mapdeckGeojsonDependency <- function() {
 #' @param data data to be used in the layer. Can be a url to GeoJSON
 #' @param stroke_colour column of an \code{sf} object, or field inside a GeoJSON \code{property} to use for colour
 #' @param stroke_opacity column of an \code{sf} object, or field inside a GeoJSON \code{property} to use for opacity
-#' @param stroke_width column of an \code{sf} object, or field inside a GeoJSON \code{property} to use for width
+#' @param stroke_width column of an \code{sf} object, or field inside a GeoJSON \code{property} to use for width (in meters)
+#' @param dash_size size of each dash, relative to the width of the stroke
+#' @param dash_gap size of the gap between dashes, relative to the width of the stroke
 #' @param fill_colour column of an \code{sf} object, or field inside a GeoJSON \code{property} to use for colour
 #' @param fill_opacity column of an \code{sf} object, or field inside a GeoJSON \code{property} to use for opacity
-#' @param radius radius of points in meters. See details
-#' @param elevation elevation of polygons. See details
+#' @param radius radius of points in meters. Default 1. See details
+#' @param elevation elevation of polygons. Default 0. See details
+#' @param extruded logical indicating if polygons should extrude from the map.
+#' If \code{TRUE}, \code{stroke_colour} for polygons is ignored
 #' @param light_settings list of light setting parameters. See \link{light_settings}
+#' @param line_width_units The units of the line width, one of 'meters', 'pixels'.
+#' When zooming in and out, meter sizes scale with the base map, and pixel sizes remain the same on screen.
+#' @param line_width_scale The line width multiplier that multiplied to all lines,
+#' including the LineString and MultiLineString features and also the outline for
+#' Polygon and MultiPolygon features if the stroked attribute is true
+#' @param line_width_min_pixels The minimum line width in pixels.
+#' @param elevation_scale Elevation multiplier. The final elevation is calculated by
+#' elevationScale * getElevation(d). elevationScale is a handy property to scale
+#' all polygon elevation without updating the data
+#' @param point_radius_scale A global radius multiplier for all points.
+#' @param point_radius_min_pixels The minimum radius in pixels.
 #' @param tooltip variable of \code{data} containing text or HTML to render as a tooltip.
 #' Only works on \code{sf} objects.
+#' @param legend either a logical indiciating if the legend(s) should be displayed, or
+#' a named list indicating which colour attributes should be included in the legend.
+#' A legend is only shown if you supply one of the colour arguments (fill or stroke)
 #'
 #' @inheritSection add_polygon data
 #' @inheritSection add_arc legend
@@ -105,10 +124,10 @@ mapdeckGeojsonDependency <- function() {
 #'
 #' ## You need a valid access token from Mapbox
 #' key <- 'abc'
+#' set_token( key )
 #'
 #' ## Not supplying colouring arguments, the function will try and find them in the GeoJSON
 #' mapdeck(
-#'  token = key
 #'  , location = c(145, -37.9)
 #'  , zoom = 8
 #'  , style = mapdeck_style("dark")
@@ -121,7 +140,6 @@ mapdeckGeojsonDependency <- function() {
 #'
 #' ## only supplying values to use for fill, the stroke will be default
 #' mapdeck(
-#'  token = key
 #'  , location = c(145, -37.9)
 #'  , zoom = 8
 #'  , style = mapdeck_style("dark")
@@ -133,7 +151,6 @@ mapdeckGeojsonDependency <- function() {
 #'  )
 #'
 #' mapdeck(
-#'  token = key
 #'  , location = c(145, -37.9)
 #'  , zoom = 8
 #'  , style = mapdeck_style("dark")
@@ -146,7 +163,6 @@ mapdeckGeojsonDependency <- function() {
 #'  )
 #'
 #' mapdeck(
-#'  token = key
 #'  , location = c(145, -37.9)
 #'  , zoom = 8
 #'  , style = mapdeck_style("dark")
@@ -167,7 +183,6 @@ mapdeckGeojsonDependency <- function() {
 #' geo <- geojsonsf::sf_geojson( sf )
 #'
 #' mapdeck(
-#'  token = key
 #'  , location = c(145, -37.9)
 #'  , zoom = 8
 #'  , style = mapdeck_style("dark")
@@ -188,10 +203,13 @@ add_geojson <- function(
 	stroke_colour = NULL,
 	stroke_opacity = NULL,
 	stroke_width = NULL,
+	dash_size = NULL,
+	dash_gap = NULL,
 	fill_colour = NULL,
 	fill_opacity = NULL,
 	radius = NULL,
 	elevation = NULL,
+	extruded = FALSE,
 	light_settings = list(),
 	legend = F,
 	legend_options = NULL,
@@ -201,8 +219,15 @@ add_geojson <- function(
 	highlight_colour = "#AAFFFFFF",
 	palette = "viridis",
 	na_colour = "#808080FF",
+	line_width_units = c("metres", "pixels"),
+	line_width_scale = 1,
+	line_width_min_pixels = 0,
+	elevation_scale = 1,
+	point_radius_scale = 1,
+	point_radius_min_pixels = 1,
 	update_view = TRUE,
 	focus_layer = FALSE,
+	digits = 6,
 	transitions = NULL
 	) {
 
@@ -210,6 +235,8 @@ add_geojson <- function(
 	l[["stroke_colour"]] <- force( stroke_colour )
 	l[["stroke_opacity"]] <- force( stroke_opacity )
 	l[["stroke_width"]] <- force( stroke_width )
+	l[["dash_size"]] <- force(dash_size)
+	l[["dash_gap"]] <- force(dash_gap)
 	l[["fill_colour"]] <- force( fill_colour )
 	l[["fill_opacity"]] <- force( fill_opacity )
 	l[["elevation"]] <- force( elevation )
@@ -226,6 +253,8 @@ add_geojson <- function(
 		!is.null( l[["stroke_colour"]] ) |
 		!is.null( l[["stroke_opacity"]] ) |
 		!is.null( l[["stroke_width"]] ) |
+		!is.null( l[["dash_size"]] ) |
+		!is.null( l[["dash_gap"]] ) |
 		!is.null( l[["fill_colour"]] ) |
 		!is.null( l[["fill_opacity"]] ) |
 		!is.null( l[["elevation"]] ) |
@@ -242,6 +271,8 @@ add_geojson <- function(
 	l <- resolve_legend_options( l, legend_options )
 	l <- resolve_geojson_data( data, l )
 
+	line_width_units <- match.arg(line_width_units)
+
 	if( !is.null(l[["data"]] ) ) {
 		data <- l[["data"]]
 		l[["data"]] <- NULL
@@ -259,7 +290,7 @@ add_geojson <- function(
 	l[["data_type"]] <- NULL
 
 	if( tp == "sf" ) {
-	  shape <- rcpp_geojson_geojson( data, l, "geometry" )
+	  shape <- rcpp_geojson_geojson( data, l, "geometry", digits)
 	  jsfunc <- "add_geojson_sf"
 	} else if ( tp == "geojson" ) {
 		## leave as is?
@@ -272,12 +303,17 @@ add_geojson <- function(
 	js_transitions <- resolve_transitions( transitions, "geojson" )
 
 	map <- addDependency(map, mapdeckGeojsonDependency())
-	shape[["legend"]] <- resolve_legend_format( shape[["legend"]], legend_format )
+	if( inherits( legend, "json" ) ) {
+		shape[["legend"]] <- legend
+	} else {
+		shape[["legend"]] <- resolve_legend_format( shape[["legend"]], legend_format )
+	}
 
 	invoke_method(
-		map, jsfunc, shape[["data"]], layer_id, light_settings, auto_highlight,
+		map, jsfunc, map_type( map ), shape[["data"]], layer_id, light_settings, auto_highlight,
 		highlight_colour, shape[["legend"]], bbox, update_view, focus_layer,
-		js_transitions
+		js_transitions, line_width_units, line_width_scale, line_width_min_pixels,
+		elevation_scale, point_radius_scale, point_radius_min_pixels, extruded
 		)
 }
 
@@ -286,5 +322,5 @@ add_geojson <- function(
 #' @export
 clear_geojson <- function( map, layer_id = NULL) {
 	layer_id <- layerId(layer_id, "geojson")
-	invoke_method(map, "md_layer_clear", layer_id, "geojson" )
+	invoke_method(map, "md_layer_clear", map_type( map ), layer_id, "geojson" )
 }
