@@ -1,6 +1,6 @@
 
 
-function add_path_geo( map_id, map_type, path_data, layer_id, auto_highlight, highlight_colour, legend, bbox, update_view, focus_layer, js_transition, billboard, brush_radius ) {
+function add_path_geo( map_id, map_type, path_data, layer_id, auto_highlight, highlight_colour, legend, bbox, update_view, focus_layer, js_transition, billboard, brush_radius, width_units, width_scale, width_min_pixels, width_max_pixels, use_offset, use_dash ) {
 
   var extensions = [];
 
@@ -8,9 +8,8 @@ function add_path_geo( map_id, map_type, path_data, layer_id, auto_highlight, hi
   	extensions.push( new deck.BrushingExtension() );
   }
 
-  var extensions = [];
   extensions.push(
-  	new deck.PathStyleExtension({dash: true})
+  	new deck.PathStyleExtension({dash: use_dash, offset: use_offset})
   );
 
   const pathLayer = new deck.PathLayer({
@@ -18,8 +17,10 @@ function add_path_geo( map_id, map_type, path_data, layer_id, auto_highlight, hi
     id: 'path-'+layer_id,
     data: path_data,
     pickable: true,
-    widthScale: 1,
-    widthMinPixels: 1,
+    widthScale: width_scale,
+    widthUnits: width_units,
+    widthMinPixels: width_min_pixels || 1,
+    widthMaxPixels: width_max_pixels || Number.MAX_SAFE_INTEGER,
     rounded: true,
     billboard: billboard,
     parameters: {
@@ -29,6 +30,7 @@ function add_path_geo( map_id, map_type, path_data, layer_id, auto_highlight, hi
     getColor: d => md_hexToRGBA( d.properties.stroke_colour ),
     getWidth: d => d.properties.stroke_width,
     getDashArray: d => [ d.properties.dash_size, d.properties.dash_gap ],
+    getOffset: d => d.properties.offset,
     onClick: info => md_layer_click( map_id, "path", info ),
     onHover: md_update_tooltip,
     autoHighlight: auto_highlight,
